<?php
/**
 * Product Table for WooCommmerce.
 *
 * @package Ecommerce_Table
 * @author  Mukul Lodhi
 * @license GPL-2.0+
 *
 * @wordpress-plugin
 * Description: Displays WooCommerce products into tabular format.
 * Author: Mukul Lodhi
 * Version: 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'ECT_Front_End' ) ) {
	/**
	 * ECT_Front_End Class
	 *
	 * @category Class
	 * @package  ECT_Front_End
	 * @author   Mukul Lodhi
	 * @license  GPL-2.0+
	 */
	class ECT_Front_End {

		/**
		 * Function ectp_div_wrapper.
		 *
		 * @param String $val Content for div.
		 * @param String $class class for div.
		 */
		public static function ectp_div_wrapper( $val, $class = '' ) {

			return "<div class='" . $class . "'>" . $val . '</div>';

		}

		/**
		 * Function div_wrapper.
		 *
		 * @param String $val Content for div.
		 * @param String $class class for div.
		 */
		public static function div_wrapper( $val, $class = '' ) {

			echo "<div class='" . esc_attr( $class ) . "'>" . esc_html( $val ) . '</div>';

		}

		/**
		 * Function ectp_anchor_wrapper.
		 *
		 * @param String $val Content for anchor.
		 * @param String $link link for anchor.
		 */
		public static function ectp_anchor_wrapper( $val, $link ) {

			return "<a href='" . esc_url( $link ) . "'>" . $val . '</a>';

		}

		/**
		 * Function ectp_p_wrapper.
		 *
		 * @param String $val Content for p tag.
		 * @param String $style style for p tag.
		 */
		public static function ectp_p_wrapper( $val, $style = '' ) {

			return "<p style='margin: 0;" . $style . "'>" . $val . '</p>';

		}

		/**
		 * Function ectp_get_cart.
		 */
		public static function ectp_get_cart() {

			global $woocommerce;

			$ectp_cart = $woocommerce->cart->get_cart();

			$ectp_cart_count = 0;

			foreach ( $ectp_cart as $key => $values ) {

				$ectp_cart_count += $values['quantity'];

			}

			echo '<img class="' . esc_attr( 'ectp_ajax_cart_image' ) . '" src="' . esc_url( plugins_url( '../assets/cart.webp', __FILE__ ) ) . '">';

			echo '<span class="' . esc_attr( 'ectp_cart_contents_count ectp_ajax_cart' ) . '" > ' . esc_html( $ectp_cart_count ) . '</span>';
		}


		/**
		 * Function ectp_get_categories.
		 *
		 * @param String $cat_ids category id.
		 */
		public static function ectp_get_categories( $cat_ids ) {

			$uri_parts = explode( '?', isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : null, 2 )[0];

			echo '<div>';

			foreach ( (array) $cat_ids as $cat_id ) {

				$cat_term = get_term_by( 'id', (int) $cat_id, 'product_cat' );

				if ( $cat_term ) {

					$ect_url = esc_url( site_url() . $uri_parts . '?cat=' . $cat_term->slug );

					echo "&nbsp;<a href='" . esc_html( wp_nonce_url( $ect_url, 'ect_nonce' ) ) . "'>";

					echo esc_html( $cat_term->name );

				}

				echo '</a>&nbsp;';

			}

			echo '</div>';

		}

		/**
		 * Function ectp_get_tags.
		 *
		 * @param String $tag_ids Tag id.
		 */
		public static function ectp_get_tags( $tag_ids ) {

			$uri_parts = explode( '?', isset( $_SERVER['REQUEST_URI'] ) ? esc_url_raw( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : null, 2 )[0];

			echo '<div>';

			foreach ( (array) $tag_ids as $tag_id ) {

				$tag_term = get_term_by( 'id', (int) $tag_id, 'product_tag' );

				if ( $tag_term ) {

					$ect_url = esc_url( site_url() . $uri_parts . '?tag=' . $tag_term->slug );

					echo "&nbsp;<a href='" . esc_html( wp_nonce_url( $ect_url, 'ect_nonce' ) ) . "'>";

					echo esc_html( $tag_term->name );

				}

				echo '</a>&nbsp;';

			}

			echo '</div>';

			return $tags;

		}


		/**
		 * Function ecpt_generate_message.
		 */
		public static function ecpt_generate_message() {

			echo '<div class="ectp_notification"></div>';

		}

		/**
		 * Function ectp_get_heading.
		 *
		 * @param String $item table heading.
		 * @param array  $ect_table_settings table settings.
		 */
		public static function ectp_get_heading( $item, $ect_table_settings ) {

			if ( 'ectp_sortable_image' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_image'] ) {

					self::div_wrapper( 'Image', 'image_padding' );

				}
			}

			if ( 'ectp_sortable_name' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_name'] ) {

					self::div_wrapper( 'Name' );

				}
			}

			if ( 'ectp_sortable_sku' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_sku'] ) {

					self::div_wrapper( 'sku' );

				}
			}

			if ( 'ectp_sortable_cat' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_categories'] ) {

					self::div_wrapper( 'Categories' );

				}
			}

			if ( 'ectp_sortable_tags' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_tags'] ) {

					self::div_wrapper( 'Tags' );
				}
			}

			if ( 'ectp_sortable_price' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_price'] ) {

					self::div_wrapper( 'Price' );

				}
			}

			if ( 'ectp_sortable_weight' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_weight'] ) {

					self::div_wrapper( 'Weight' );

				}
			}

			if ( 'ectp_sortable_dimentions' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_dimention'] ) {

					self::div_wrapper( 'Dimention' );

				}
			}

			if ( 'ectp_sortable_stock' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_stock_status'] ) {

					self::div_wrapper( 'Status' );

				}
			}

			if ( 'ectp_sortable_quantity' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_stock_quantity'] ) {

					self::div_wrapper( 'Quantity' );

				}
			}

			if ( 'ectp_sortable_desc' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_short_description'] ) {

					self::div_wrapper( 'Description' );

				}
			}
		}

		/**
		 * Function ectp_get_tabledata.
		 *
		 * @param String $item table heading.
		 * @param array  $ect_table_settings table settings.
		 * @param array  $ect_product product array.
		 * @param int    $post_id post id.
		 */
		public static function ectp_get_tabledata( $item, $ect_table_settings, $ect_product, $post_id ) {

			if ( 'ectp_sortable_image' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_image'] ) {

					$size = $ect_table_settings['ect_image_size'];

					$image = $ect_product->get_image( array( $size, $size ) );

					echo '<div class="' . esc_attr( 'ect_image_' . $post_id ) . '">
					' . wp_kses_post( $image ) . '</div>';

				}
			}

			if ( 'ectp_sortable_name' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_name'] ) {

					echo '<div class="' . esc_attr( 'ect_title_' . $post_id ) . '">
					<a href="' . esc_url( get_permalink() ) . '">' . esc_html( $ect_product->get_data()['name'] ) . '</a>
					</div>';

				}
			}

			if ( 'ectp_sortable_sku' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_sku'] ) {

					if ( '' !== $ect_product->get_data()['sku'] ) {

						self::div_wrapper( '#' . $ect_product->get_data()['sku'] );

					} else {

						self::div_wrapper( '-' );

					}
				}
			}

			if ( 'ectp_sortable_cat' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_categories'] ) {

					if ( isset( $ect_product->get_category_ids()[0] ) ) {

						self::ectp_get_categories( $ect_product->get_category_ids() );

					} else {

						self::div_wrapper( esc_html( '-' ) );

					}
				}
			}

			if ( 'ectp_sortable_tags' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_tags'] ) {

					if ( isset( $ect_product->get_tag_ids()[0] ) ) {

						self::ectp_get_tags( $ect_product->get_tag_ids() );

					} else {

						self::div_wrapper( esc_html( '-' ) );

					}
				}
			}

			if ( 'ectp_sortable_price' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_price'] ) {

					if ( '' !== $ect_product->get_data()['price'] ) {

						if ( $ect_product->get_data()['price'] !== $ect_product->get_data()['regular_price'] ) {

							if ( strlen( $ect_product->get_data()['regular_price'] ) > 0 ) {

								echo '<div class="ect_price"><p style="margin: 0;text-decoration: line-through;">' . esc_html( get_woocommerce_currency_symbol() . $ect_product->get_data()['regular_price'] ) . '</p>&nbsp;' . esc_html( '&nbsp;' . get_woocommerce_currency_symbol() . $ect_product->get_data()['price'] ) . '</div>';

							} else {

								self::div_wrapper( get_woocommerce_currency_symbol() . $ect_product->get_data()['price'], 'ect_price' );

							}
						} else {

							self::div_wrapper( get_woocommerce_currency_symbol() . $ect_product->get_data()['price'], 'ect_price' );

						}
					} else {

						self::div_wrapper( esc_html( '-' ) );

					}
				}
			}

			if ( 'ectp_sortable_weight' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_weight'] ) {

					if ( '' !== $ect_product->get_data()['weight'] ) {

						self::div_wrapper( $ect_product->get_data()['weight'] . ' Kg' );

					} else {

						self::div_wrapper( '-' );

					}
				}
			}

			if ( 'ectp_sortable_dimentions' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_dimention'] ) {

					if ( '' !== $ect_product->get_data()['length'] || '' !== $ect_product->get_data()['width'] || '' !== $ect_product->get_data()['height'] ) {

						self::div_wrapper( $ect_product->get_data()['length'] . ' x ' . $ect_product->get_data()['width'] . ' x ' . $ect_product->get_data()['height'] . ' cm' );

					} else {

						self::div_wrapper( '-' );

					}
				}
			}

			if ( 'ectp_sortable_stock' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_stock_status'] ) {

					if ( '' !== $ect_product->get_data()['stock_status'] ) {

						self::div_wrapper( $ect_product->get_data()['stock_status'], 'ect_stock' );

					} else {

						self::div_wrapper( '-' );

					}
				}
			}

			if ( 'ectp_sortable_quantity' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_stock_quantity'] ) {

					if ( '' !== $ect_product->get_data()['stock_quantity'] ) {

						self::div_wrapper( $ect_product->get_data()['stock_quantity'] . ' In Stock' );

					} else {

						self::div_wrapper( '-' );

					}
				}
			}

			if ( 'ectp_sortable_desc' === $item ) {

				if ( 'checked' === $ect_table_settings['ect_short_description'] ) {

					if ( '' !== $ect_product->get_data()['short_description'] ) {

						self::div_wrapper( $ect_product->get_data()['short_description'] );

					} else {

						self::div_wrapper( '-' );

					}
				}
			}
		}

		/**
		 * Function ectp_get_fraction.
		 *
		 * @param array $ect_table_settings settings.
		 */
		public static function ectp_get_fraction( $ect_table_settings ) {

			$attr = '';

			$ectp_list = explode( ',', $ect_table_settings ['ectp_sort_list'] );

			foreach ( $ectp_list as $item ) {

				if ( 'ectp_sortable_image' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_image'] ) {

						$attr .= ' 1fr';
					}
				}

				if ( 'ectp_sortable_name' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_name'] ) {

						$attr .= ' 1.2fr';
					}
				}

				if ( 'ectp_sortable_sku' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_sku'] ) {

						$attr .= ' 1.5fr';
					}
				}

				if ( 'ectp_sortable_cat' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_categories'] ) {

						$attr .= ' 1fr';
					}
				}

				if ( 'ectp_sortable_tags' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_tags'] ) {

						$attr .= ' 1fr';
					}
				}

				if ( 'ectp_sortable_price' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_price'] ) {

						$attr .= ' 0.7fr';
					}
				}

				if ( 'ectp_sortable_weight' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_weight'] ) {

						$attr .= ' 0.5fr';
					}
				}

				if ( 'ectp_sortable_dimentions' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_dimention'] ) {

						$attr .= ' 1fr';
					}
				}

				if ( 'ectp_sortable_stock' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_stock_status'] ) {

						$attr .= ' 0.7fr';
					}
				}

				if ( 'ectp_sortable_quantity' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_stock_quantity'] ) {

						$attr .= ' 0.5fr';
					}
				}

				if ( 'ectp_sortable_desc' === $item ) {

					if ( 'checked' === $ect_table_settings ['ect_short_description'] ) {

						$attr .= ' 1.5fr';
					}
				}
			}

			return $attr;
		}

		/**
		 * Function get_var_fraction.
		 *
		 * @param array $attr product attribute.
		 */
		public static function get_var_fraction( $attr ) {
			$size = count( $attr['attributes'] );
			$size = '1fr 2fr 1fr 0.5fr';
			return $size;
		}

		/**
		 * Function ectp_generate_heading.
		 *
		 * @param array $ect_table_settings settings.
		 */
		public static function ectp_generate_heading( $ect_table_settings ) {

			$ectp_list = explode( ',', $ect_table_settings ['ectp_sort_list'] );

			foreach ( $ectp_list as $list_item ) {

				self::ectp_get_heading( $list_item, $ect_table_settings );

			}
			?>

			<div class="<?php echo esc_attr( 'ectp_cart_align' ); ?>">
				<div><?php echo esc_html( 'Add To Cart' ); ?></div>
				<div>
				</div>
			</div>

			<?php

		}

		/**
		 * Function ectp_generate_table.
		 *
		 * @param array $ect_product product array.
		 * @param int   $post_id Post Id.
		 * @param array $ect_table_settings settings.
		 * @param array $ect_table_options options.
		 */
		public static function ectp_generate_table( $ect_product, $post_id, $ect_table_settings, $ect_table_options ) {

			$ectp_list = explode( ',', $ect_table_settings ['ectp_sort_list'] );

			foreach ( $ectp_list as $list_item ) {

				self::ectp_get_tabledata( $list_item, $ect_table_settings, $ect_product, $post_id );

			}

			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50 );
			remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_after_shop_loop_item', 5 );
			remove_action( 'woocommerce_single_variation', 'woocommerce_single_variation', 10 );
			add_filter( 'woocommerce_get_stock_html', '__return_empty_string' );

			if ( isset( get_post_meta( $post_id, '_product_url' )[0] ) ) {

				echo '<a href="' . esc_url( get_post_meta( $post_id, '_product_url' )[0] ) . '"><button type="submit" name="add-to-cart" value="' . esc_attr( $post_id ) . '" class="single_add_to_cart_button button alt">';
				echo esc_html( get_post_meta( esc_attr( $post_id ), '_button_text' )[0] ) . '</button></a>';

			} elseif ( isset( get_post_meta( $post_id, '_children' )[0] ) ) {

				echo '<a href="' . esc_url( get_permalink( $post_id ) ) . '"><button type="submit" name="add-to-cart" value="' . esc_attr( $post_id ) . '" class="single_add_to_cart_button button alt">';
				echo 'View Products</button></a>';

			} else {

				echo '<div>';

				if ( $ect_product->has_child() && 'checked' === $ect_table_options['ect_variations_table'] ) {

					echo esc_html( '' );

				} else {

					do_action( 'woocommerce_single_product_summary' );

				}

				echo '</div>';
			}
		}

		/**
		 * Function ectp_variable_table.
		 *
		 * @param array $attr product attribute.
		 * @param int   $post_id Post Id.
		 * @param array $ect_table_settings settings.
		 * @param array $ect_table_options options.
		 */
		public static function ectp_variable_table( $attr, $post_id, $ect_table_settings, $ect_table_options ) {

			if ( 'checked' === $ect_table_settings['ect_image'] ) {

				$size  = $ect_table_settings['ect_image_size'];
				$image = wp_get_attachment_image_url( $attr['image_id'], array( $size, $size ) );
				echo '<div class="' . esc_attr( 'ect_image_' . $post_id ) . '">
				<img width="' . esc_html( $size ) . '" height="' . esc_html( $size ) . '" 
				src="' . esc_html( $image ) . '">
				</div>';
			}

			if ( '' !== $attr['variation_description'] ) {
				self::div_wrapper( wp_trim_words( $attr['variation_description'], 10 ) );
			} else {
				self::div_wrapper( '-' );
			}

			echo '<div class="' . esc_html( 'ect_capitalize' ) . '">';
			foreach ( $attr['attributes'] as $key => $single_attr ) {
				$name = $key;
				echo '<input type="hidden" name="' . esc_html( $key ) . '" value="' . esc_html( $single_attr ) . '">';
				$key = str_replace( 'attribute_', '', $key );
				if ( empty( $single_attr ) ) {
					$terms = get_terms( $key );
					$key   = str_replace( 'pa_', '', $key );
					echo esc_html( $key ) . ': ';
					echo '<select class="ect_variation_attr" name="' . esc_html( $name ) . '"><option>Choose</option>';
					foreach ( $terms as $term ) {
						echo '<option value="' . esc_html( $term->slug ) . '">' . esc_html( $term->name );
					}
					echo '</select><br>';
				} else {
					$key = str_replace( 'pa_', '', $key );
					echo esc_html( $key . ': ' . $single_attr ) . '<br>';
				}
			}
			echo '</div>';

			if ( 'checked' === $ect_table_settings['ect_price'] ) {

				if ( '' !== $attr['display_price'] ) {

					if ( $attr['display_price'] !== $attr['display_regular_price'] ) {

						if ( strlen( $attr['display_regular_price'] ) > 0 ) {

							echo '<div class="ect_price"><p style="margin: 0;text-decoration: line-through;">' . esc_html( get_woocommerce_currency_symbol() . $attr['display_regular_price'] ) . '</p>&nbsp;' . esc_html( '&nbsp;' . get_woocommerce_currency_symbol() . $attr['display_price'] ) . '</div>';

						} else {

							self::div_wrapper( get_woocommerce_currency_symbol() . $attr['display_price'], 'ect_price' );

						}
					} else {

						self::div_wrapper( get_woocommerce_currency_symbol() . $attr['display_price'], 'ect_price' );

					}
				} else {

					self::div_wrapper( esc_html( '-' ) );

				}
			}
			?>
			<div class="single_variation_wrap">
				<form class="variations_form cart">
					<div class="woocommerce-variation-add-to-cart variations_button">

						<div class="quantity">
							<input type="number" class="input-text qty text" step="1" min="1" max="" name="quantity" value="1" title="Qty" size="4" placeholder="" inputmode="numeric">
						</div>

						<button type="button" class="single_add_to_cart_button button alt">Add to cart</button>

						<input type="hidden" name="add-to-cart" value="<?php echo esc_html( $post_id ); ?>">
						<input type="hidden" name="product_id" value="<?php echo esc_html( $post_id ); ?>">
						<input type="hidden" name="variation_id" class="variation_id" value="<?php echo esc_html( $attr['variation_id'] ); ?>">
						<input type="hidden" name="ect_variation_type" value="<?php echo esc_html( 'table' ); ?>">
					</div>
				</form>
			</div>
			<?php
		}
	}
}
