<?php
/**
 * Product Table for WooCommerce.
 *
 * @package Ecommerce_Table
 * @author  Mukul Lodhi
 * @license GPL-2.0+
 *
 * @wordpress-plugin
 * Description: This Plugin displays products in tabular format.
 * Author: Mukul Lodhi
 * Version: 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Ect_Table_Activator' ) ) {

	/**
	 * Ect_Table_Activator Class
	 *
	 * @category Class
	 * @package  Ect_Table_Activator
	 * @author   Mukul Lodhi
	 * @license  GPL-2.0+
	 */
	class Ect_Table_Activator {
		/**
		 * Function deactivate activates ecommerce table plugin.
		 */
		public static function activate() {

			if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

				$ect_table_settings = get_option( 'ect_table_settings' );
				$ect_table_options  = get_option( 'ect_table_options' );

				$defaults = array(
					'version'               => '1.2.2',
					'enabled'               => 'yes',
					'ect_display_count'     => 10,
					'ect_price'             => 'checked',
					'ect_stock_quantity'    => '',
					'ect_stock_status'      => 'checked',
					'ect_dimention'         => '',
					'ect_weight'            => '',
					'ect_short_description' => 'checked',
					'ect_sku'               => '',
					'ect_name'              => 'checked',
					'ect_categories'        => 'checked',
					'ect_row_count'         => 6,
					'ect_image_size'        => 100,
					'ect_image'             => 'checked',
					'ect_tags'              => '',
					'ect_currency'          => '',
					'ect_table_name'        => 'Default',
					'ectp_sort_list'        => 'ectp_sortable_image,ectp_sortable_name,ectp_sortable_sku,ectp_sortable_stock,ectp_sortable_desc,ectp_sortable_quantity,ectp_sortable_weight,ectp_sortable_dimentions,ectp_sortable_cat,ectp_sortable_price,ectp_sortable_tags',
				);

				$option_defaults = array(
					'ect_featured_products' => '',
					'ect_instock'           => '',
					'ect_variations_table'  => '',
				);

				$ect_table_settings = wp_parse_args( $ect_table_settings, $defaults );
				$ect_table_options  = wp_parse_args( $ect_table_options, $option_defaults );

				update_option( 'ect_table_settings', $ect_table_settings );
				update_option( 'ect_table_options', $ect_table_options );
				update_option( 'ect_table_counter', 1 );

			} else {

				deactivate_plugins( plugin_basename( __FILE__ ) );
				wp_die( esc_html_e( 'This plugin requires Woocommerce' ) );

			}
		}
	}
}
