<?php
/**
 * Product Table for WooCommerce.
 *
 * @package Ecommerce_Table
 * @author  Mukul Lodhi
 * @license GPL-2.0+
 *
 * @wordpress-plugin
 * Description: This Plugin displays products in tabular format.
 * Author: Mukul Lodhi
 * Version: 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'ECT_Table_Admin' ) ) {

	/**
	 * ECT_Table_Admin Class
	 *
	 * @category Class
	 * @package  ECT_Table_Admin
	 * @author   Mukul Lodhi
	 * @license  GPL-2.0+
	 */
	class ECT_Table_Admin {

		/**
		 * Function ectp_update_values.
		 *
		 * @param bool $new add new table.
		 */
		public static function ectp_update_values( $new = false ) {

			if ( isset( $_POST['ect_admin_nonce'] ) ) {

				$nonce = sanitize_text_field( wp_unslash( $_POST['ect_admin_nonce'] ) );

				if ( ! wp_verify_nonce( $nonce, 'ect_nonce_action' ) ) {

					die( 'Nonce value cannot be verified.' );

				} else {

					$ect_table_counter = (int) get_option( 'ect_table_counter' );

					$id = (int) sanitize_text_field( wp_unslash( isset( $_POST['ectp_table_id'] ) ? $_POST['ectp_table_id'] : null ) );
					if ( $new ) {
						$id = $ect_table_counter + 1;
					}
					if ( 1 === $id ) {
						$id = null;
					}

					$ect_table_settings    = get_option( 'ect_table_settings' . $id );
					$ect_table_options     = get_option( 'ect_table_options' . $id );
					$ect_image             = false;
					$ect_price             = false;
					$ect_stock_quantity    = false;
					$ect_stock_status      = false;
					$ect_weight            = false;
					$ect_dimention         = false;
					$ect_short_description = false;
					$ect_sku               = false;
					$ect_name              = false;
					$ect_categories        = false;
					$ect_tags              = false;
					$ect_featured_products = false;
					$ect_instock           = false;
					$ect_variations_table  = false;

					$ectp_sort_list    = sanitize_text_field( wp_unslash( isset( $_POST['ectp_sort_list'] ) ? $_POST['ectp_sort_list'] : null ) );
					$ect_display_count = sanitize_text_field( wp_unslash( isset( $_POST['ect_count'] ) ? $_POST['ect_count'] : null ) );
					$ect_image_size    = sanitize_text_field( wp_unslash( isset( $_POST['ect_image_size'] ) ? $_POST['ect_image_size'] : null ) );

					if ( isset( $_POST['ect_image'] ) && 'on' === $_POST['ect_image'] ) {
						$ect_image = 'checked';
					}

					if ( isset( $_POST['ect_price'] ) && 'on' === $_POST['ect_price'] ) {
						$ect_price = 'checked';
					}

					if ( isset( $_POST['ect_stock_quantity'] ) && 'on' === $_POST['ect_stock_quantity'] ) {
						$ect_stock_quantity = 'checked';
					}

					if ( isset( $_POST['ect_stock_status'] ) && 'on' === $_POST['ect_stock_status'] ) {
						$ect_stock_status = 'checked';
					}

					if ( isset( $_POST['ect_weight'] ) && 'on' === $_POST['ect_weight'] ) {
						$ect_weight = 'checked';
					}

					if ( isset( $_POST['ect_dimention'] ) && 'on' === $_POST['ect_dimention'] ) {
						$ect_dimention = 'checked';
					}

					if ( isset( $_POST['ect_short_description'] ) && 'on' === $_POST['ect_short_description'] ) {
						$ect_short_description = 'checked';
					}

					if ( isset( $_POST['ect_sku'] ) && 'on' === $_POST['ect_sku'] ) {
						$ect_sku = 'checked';
					}

					if ( isset( $_POST['ect_name'] ) && 'on' === $_POST['ect_name'] ) {
						$ect_name = 'checked';
					}

					if ( isset( $_POST['ect_categories'] ) && 'on' === $_POST['ect_categories'] ) {
						$ect_categories = 'checked';
					}

					if ( isset( $_POST['ect_tags'] ) && 'on' === $_POST['ect_tags'] ) {
						$ect_tags = 'checked';
					}

					if ( isset( $_POST['ect_featured_products'] ) && 'on' === $_POST['ect_featured_products'] ) {
						$ect_featured_products = 'checked';
					}

					if ( isset( $_POST['ect_instock'] ) && 'on' === $_POST['ect_instock'] ) {
						$ect_instock = 'checked';
					}

					if ( isset( $_POST['ect_variations_table'] ) && 'on' === $_POST['ect_variations_table'] ) {
						$ect_variations_table = 'checked';
					}

					$ect_table_settings['ect_display_count']     = $ect_display_count;
					$ect_table_settings['ectp_sort_list']        = $ectp_sort_list;
					$ect_table_settings['ect_image_size']        = $ect_image_size;
					$ect_table_settings['ect_image']             = $ect_image;
					$ect_table_settings['ect_price']             = $ect_price;
					$ect_table_settings['ect_stock_quantity']    = $ect_stock_quantity;
					$ect_table_settings['ect_stock_status']      = $ect_stock_status;
					$ect_table_settings['ect_dimention']         = $ect_dimention;
					$ect_table_settings['ect_weight']            = $ect_weight;
					$ect_table_settings['ect_short_description'] = $ect_short_description;
					$ect_table_settings['ect_sku']               = $ect_sku;
					$ect_table_settings['ect_name']              = $ect_name;
					$ect_table_settings['ect_categories']        = $ect_categories;
					$ect_table_settings['ect_tags']              = $ect_tags;
					$ect_table_settings['ect_row_count']         = sanitize_text_field( wp_unslash( isset( $_POST['ect_row_count'] ) ? $_POST['ect_row_count'] : null ) );
					$ect_table_settings['ect_table_name']        = sanitize_text_field( wp_unslash( isset( $_POST['tablename'] ) ? $_POST['tablename'] : null ) );
					$ect_table_settings['ect_currency']          = get_woocommerce_currency_symbol();
					$ect_table_options['ect_featured_products']  = $ect_featured_products;
					$ect_table_options['ect_instock']            = $ect_instock;
					$ect_table_options['ect_variations_table']   = $ect_variations_table;

					update_option( 'ect_table_settings' . $id, $ect_table_settings );
					update_option( 'ect_table_options' . $id, $ect_table_options );

					if ( $new ) {
						$ect_table_counter++;
						update_option( 'ect_table_counter', $ect_table_counter );
						wp_safe_redirect( wp_nonce_url( admin_url( 'admin.php?page=ectp-table&ect_edit_table=true&ectp_table_id=' . $ect_table_counter ), 'ect_admin_nonce' ) );
						exit;
					}
					return 'Table Updated Successfully';
				}
			}
		}

		/**
		 * Function ectp_get_item.
		 *
		 * @param array $ectp_args args name.
		 * @param array $ect_table_settings table settings.
		 */
		public static function ectp_get_item( $ectp_args, $ect_table_settings ) {

			if ( 'ectp_sortable_image' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_image"' . esc_html( $ect_table_settings['ect_image'] ) . '>
									<label for="regular_price">Image</label><br>';

			}

			if ( 'ectp_sortable_price' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_price"' . esc_html( $ect_table_settings['ect_price'] ) . ' >
									<label for="price">Price</label><br>';

			}

			if ( 'ectp_sortable_quantity' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_stock_quantity"' . esc_html( $ect_table_settings['ect_stock_quantity'] ) . ' >
									<label for="stock_quantity">Stock Quantity</label><br>';

			}

			if ( 'ectp_sortable_stock' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_stock_status"' . esc_html( $ect_table_settings['ect_stock_status'] ) . ' >
									<label for="stock_status">Stock Status</label><br>';

			}

			if ( 'ectp_sortable_weight' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_weight"' . esc_html( $ect_table_settings['ect_weight'] ) . ' >
									<label for="weight">Weight</label><br>';

			}

			if ( 'ectp_sortable_dimentions' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_dimention"' . esc_html( $ect_table_settings['ect_dimention'] ) . ' >
									<label for="dimention">Dimention</label><br>';

			}

			if ( 'ectp_sortable_desc' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_short_description"' . esc_html( $ect_table_settings['ect_short_description'] ) . ' >
									<label for="short_description">Short Description</label><br>';

			}

			if ( 'ectp_sortable_sku' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_sku"' . esc_html( $ect_table_settings['ect_sku'] ) . ' >
									<label for="sku">sku</label><br>';

			}

			if ( 'ectp_sortable_name' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_name"' . esc_html( $ect_table_settings['ect_name'] ) . ' >
									<label for="name">Name</label><br>';

			}

			if ( 'ectp_sortable_cat' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_categories"' . esc_html( $ect_table_settings['ect_categories'] ) . ' >
									<label for="categories">Categories</label><br>';

			}

			if ( 'ectp_sortable_tags' === $ectp_args ) {

				echo '<input type="checkbox" name="ect_tags"' . esc_html( $ect_table_settings['ect_tags'] ) . ' >
									<label for="tags">Tags</label><br>';

			}

		}

		/**
		 * Function add_ect_table.
		 *
		 * @param int  $ect_table_id table id.
		 * @param bool $new new table.
		 * @param bool $edit edit table.
		 */
		public static function edit_ect_table( $ect_table_id = '', $new = false, $edit = false ) {

			$update = $new ? self::ectp_update_values( $new ) : self::ectp_update_values();
			$id     = $ect_table_id;

			if ( 1 === $ect_table_id ) {
				$id = '';
			}
			$ect_table_settings = get_option( 'ect_table_settings' . $id );
			$ect_table_options  = get_option( 'ect_table_options' . $id );
			$ect_table_counter  = get_option( 'ect_table_counter' );
			$row_count          = 0;

			foreach ( $ect_table_settings as $ect_single ) {

				if ( 'checked' === $ect_single ) {
					$row_count++;
				}
			}

			$ect_table_settings['ect_row_count'] = $row_count;
			update_option( 'ect_table_settings' . $id, $ect_table_settings );

			?>

			<div class="ect_wrapper">
				<form id="ectp_admin_form" action="" method="POST">
				<?php
				if ( $new ) {
					echo '<h1>Add New</h1>
					<span>Table Name</span><br>
					<input type="text" name="tablename" >';
				}
				if ( $edit ) {
					echo '<h1>Edit Table</h1>';
				}
				if ( null !== $update ) {
					echo '<div class="ect_message">' . esc_html( $update ) . '</div>';
				}
				?>

					<div class="ect_admin_options" style="display:grid; grid-template-columns: 1fr 3fr;">
						<div>
						<?php
						if ( $edit ) {
							echo '<span>Table Name</span><br>
								<input type="text" name="tablename" value="' . esc_html( $ect_table_settings['ect_table_name'] ) . '"><br>';
						}
						?>
							<span>Set Display Count</span><br>
							<input type="text" name="ect_count" id="" value="<?php echo esc_html( $ect_table_settings['ect_display_count'] ); ?>"><br>
							<span>Set Image size (:px)</span><br>
							<input type="text" name="ect_image_size" id="" value="<?php echo esc_html( $ect_table_settings['ect_image_size'] ); ?>">
							<h4>Choose and Arrange Fields to display</h4>
							<ul id="ectp_sortable_list">

							<?php

							$ectp_list = explode( ',', $ect_table_settings['ectp_sort_list'] );

							foreach ( $ectp_list as $list_item ) {
								echo '<li id="' . esc_attr( $list_item ) . '">';

								self::ectp_get_item( $list_item, $ect_table_settings );

								echo '</li>';
							}

							?>

							</ul>
							<input type="hidden" name="ect_row_count" value="<?php echo esc_html( $row_count ); ?>">
							<input type="hidden" name="ectp_sort_list">
							<input type="hidden" name="ectp_table_id" value="<?php echo esc_html( $ect_table_id ); ?>">
							<input type="hidden" name="ectp_table_counter" value="<?php echo esc_html( $ect_table_counter ); ?>">
							<div>
								<input name="ect_update" type="submit" value="Update">
								<?php wp_nonce_field( 'ect_nonce_action', 'ect_admin_nonce' ); ?>
							</div>
						</div>
						<div>
							<h3>Display Options</h3>
							<h4>Sort By</h4>
							<input type="checkbox" name="ect_featured_products" <?php echo esc_html( $ect_table_options['ect_featured_products'] ); ?> >
							<label for="price">Featured Products</label><br>
							<input type="checkbox" name="ect_instock" <?php echo esc_html( $ect_table_options['ect_instock'] ); ?> >
							<label for="price">In Stock</label><br>
							<input type="checkbox" name="ect_variations_table" <?php echo esc_html( $ect_table_options['ect_variations_table'] ); ?> >
							<label for="price">Include Variations in Table (Beta)</label><br>
						</div> 
					</div>
				</form>
			<?php
			if ( ! $new ) {
				?>
				<div><p>Copy and paste shortcode <code>[ect-table id="<?php echo esc_html( $ect_table_id ); ?>"]</code> to page</p></div>
				<div><p>Or Copy shortcode to theme  </p></div>
				<div><code>&lt;&#63;php echo do_shortcode( '[ect-table id="<?php echo esc_html( $ect_table_id ); ?>"]' ); &#63;&gt;</code></div>
				<?php
			}
			?>
			</div>

			<?php

		}
		/**
		 * Function ect_table_screen Home screen.
		 */
		public static function ect_table_screen() {

			echo '<div class="ect_admin_table_wrapper"><h1>Ecommerce Table</h1>
			<a href="' . esc_html( wp_nonce_url( admin_url( 'admin.php?page=ectp-table&ect_new_table=true' ), 'ect_admin_nonce' ) ) . '"><button>Add New</button></a>
			<br><br>
			<table class="ect_admin_table">
			<thead><tr>
			
			<td>Name</td>
			<td>Shortcode</td>
			<td>Options</td>
			</tr></thead><tbody>';
			$ect_table_counter = (int) get_option( 'ect_table_counter' );
			for ( $i = 1; $i <= $ect_table_counter; $i++ ) {

				$number = ( 1 === $i ) ? '' : $i;

				$ect_table_settings = get_option( 'ect_table_settings' . $number );
				$ect_table_options  = get_option( 'ect_table_options' . $number );
				if ( false === $ect_table_settings ) {
					continue;
				} else {
					// add nonce and delete.
					echo '<tr>
					
					<td>' . esc_html( $ect_table_settings['ect_table_name'] ) . '</td>
					<td><code>[ect-table id="' . esc_html( $i ) . '"]</code></td>
					<td><a href="' . esc_html( wp_nonce_url( admin_url( 'admin.php?page=ectp-table&ect_edit_table=true&ectp_table_id=' . $i ), 'ect_admin_nonce' ) ) . '">edit</a> | <a href="' . esc_html( wp_nonce_url( admin_url( 'admin.php?page=ectp-table&ect_delete_item=' . $i ), 'ect_admin_nonce' ) ) . '">delete</a></td>
					</tr>';
				}
			}
			echo '</tbody></table></div>';
		}
		/**
		 * Function add_new_table.
		 */
		public static function add_new_table() {
			self::edit_ect_table( null, true );
		}
		/**
		 * Delete table from id.
		 *
		 * @param int $id delete id.
		 */
		public static function delete_table( $id ) {

			$id = ( 1 === $id ) ? '' : $id;
			delete_option( 'ect_table_settings' . $id );
			delete_option( 'ect_table_options' . $id );
		}
	}
}
