<?php
/**
 * Product Table for WooCommerce.
 *
 * @package Ecommerce_Table
 * @author  Mukul Lodhi
 * @license GPL-2.0+
 *
 * @wordpress-plugin
 * Description: This Plugin displays products in tabular format.
 * Author: Mukul Lodhi
 * Version: 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'ectp_generate_heading' ) ) {
	/**
	 * Function ectp_product_update.
	 */
	function ectp_product_update() {

		if ( isset( $_POST['nonce'] ) ) {
			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );

			if ( ! wp_verify_nonce( $nonce, 'ect-ajax-nonce' ) ) {
				die( 'Nonce value cannot be verified.' );
			}
			$product_id   = apply_filters( 'woocommerce_add_to_cart_product_id', absint( sanitize_text_field( wp_unslash( isset( $_POST['post_id'] ) ? $_POST['post_id'] : null ) ) ) );
			$quantity     = empty( sanitize_text_field( wp_unslash( isset( $_POST['quantity'] ) ? $_POST['quantity'] : null ) ) ) ? 1 : wc_stock_amount( sanitize_text_field( wp_unslash( isset( $_POST['quantity'] ) ? $_POST['quantity'] : null ) ) );
			$variation_id = absint( sanitize_text_field( wp_unslash( isset( $_POST['var_id'] ) ? $_POST['var_id'] : null ) ) );

			wc_stock_amount( sanitize_text_field( wp_unslash( isset( $_POST['quantity'] ) ? $_POST['quantity'] : null ) ) );

			$passed_validation = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity );
			$product_status    = get_post_status( $product_id );
			$variation         = array();

			if ( null !== $variation_id ) {
				$variation         = json_decode( sanitize_text_field( wp_unslash( isset( $_POST['variation'] ) ? $_POST['variation'] : null ) ), true );
				$passed_validation = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity, $variation_id, $variation );
			}

			if ( $passed_validation && false !== WC()->cart->add_to_cart( $product_id, $quantity, $variation_id, $variation ) && 'publish' === $product_status ) {
				echo 'added';
			} else {
				$data = array(
					'error'       => true,
					'product_url' => apply_filters( 'woocommerce_cart_redirect_after_error', get_permalink( $product_id ), $product_id ),
				);
				echo wp_json_encode( $data );
			}
			die();
		}
		die();
	}
}
add_action( 'wp_ajax_ectp_product_update', 'ectp_product_update' );
add_action( 'wp_ajax_nopriv_ectp_product_update', 'ectp_product_update' );
