<?php
/**
 * Product Table for WooCommerce.
 *
 * @package     Ecommerce_Table
 * @author      Mukul Lodhi
 * @license     GPL-2.0+
 *
 * @wordpress-plugin
 * Description: This Plugin displays products in tabular format.
 * Author: Mukul Lodhi
 * Version: 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

require plugin_dir_path( __FILE__ ) . 'class-ect-front-end.php';
require plugin_dir_path( __FILE__ ) . 'ect-add-to-cart.php';
require plugin_dir_path( __FILE__ ) . 'ect-table-admin.php';

if ( ! function_exists( 'ectp_table_scripts' ) ) {
	/** Assign style to table */
	function ectp_table_scripts() {

		wp_enqueue_style( 'ectp_table_style', plugins_url( '../assets/ect_table_style.css', __FILE__ ), array(), '1.0.0' );

	}
}

if ( function_exists( 'ectp_table_scripts' ) ) {

	add_action( 'wp_enqueue_scripts', 'ectp_table_scripts' );

}

if ( ! function_exists( 'ectp_ajax_handle' ) ) {
	/** Add table javascript */
	function ectp_ajax_handle() {

		wp_enqueue_script( 'ect_ajax_path_handle', plugins_url( '../assets/ect_table_script.js', __FILE__ ), array( 'jquery' ), '1.0.0', false );
		$translation_array = array(
			'ajax_path' => admin_url( 'admin-ajax.php' ),
			'nonce'     => wp_create_nonce( 'ect-ajax-nonce' ),
		);
		wp_localize_script( 'ect_ajax_path_handle', 'ajax_object', $translation_array );
		wp_enqueue_script( 'ect_ajax_path_handle' );
	}
}

if ( function_exists( 'ectp_ajax_handle' ) ) {

	add_action( 'wp_enqueue_scripts', 'ectp_ajax_handle' );

}


if ( ! function_exists( 'ectp_admin_page_script' ) ) {
	/** Add admin scripts */
	function ectp_admin_page_script() {

		global $pagenow;

		if ( 'admin.php' !== $pagenow ) {
			return;
		}

		wp_register_style( 'ectp-admin-style', plugins_url( '../assets/ectp_admin_style.css', __FILE__ ), array(), '1.0.0' );
		wp_enqueue_style( 'ectp-admin-style' );

		wp_register_script( 'ectp-admin-script', plugins_url( '../assets/ectp_admin_script.js', __FILE__ ), array( 'jquery' ), '1.0.0', true );
		wp_enqueue_script( 'ectp-admin-script' );
	}
}

if ( function_exists( 'ectp_admin_page_script' ) ) {

	add_action( 'admin_enqueue_scripts', 'ectp_admin_page_script' );

}

if ( ! function_exists( 'ectp_settings_link' ) ) {
	/**
	 * Add settings link to plugin.
	 *
	 * @param array $links settings.
	 */
	function ectp_settings_link( $links ) {
		$link[] = '<a href="' . admin_url( 'admin.php?page=ectp-table' ) . '">' . esc_html( 'Settings' ) . '</a>';
		return array_merge( $link, $links );
	}
}

if ( ! function_exists( 'ectp_tabular_posts' ) ) {
	/**
	 * Generate table.
	 *
	 * @param int $atts table id.
	 */
	function ectp_tabular_posts( $atts ) {
		$ect_sc_attr = shortcode_atts(
			array(
				'id' => '',
			),
			$atts
		);

		$id = ( '1' === $ect_sc_attr['id'] ) ? '' : $ect_sc_attr['id'];
		ob_start();
		$ect_table_settings     = get_option( 'ect_table_settings' . $id );
		$ect_table_options      = get_option( 'ect_table_options' . $id );
		$count                  = $ect_table_settings['ect_display_count'];
		$ect_tax_query_featured = '';
		$ect_meta_query         = '';
		$ect_tax_query_cat      = '';
		$ect_tax_query_tag      = '';

		if ( 'checked' === $ect_table_options ['ect_featured_products'] ) {

			$ect_tax_query_featured = array(
				'taxonomy' => 'product_visibility',
				'field'    => 'name',
				'terms'    => 'featured',
			);
		}

		if ( 'checked' === $ect_table_options ['ect_instock'] ) {

			$ect_meta_query = array(
				array(
					'key'     => '_stock_status',
					'value'   => 'instock',
					'compare' => '=',
				),
			);
		}

		if ( isset( $_GET ['_wpnonce'] ) ) {

			$nonce = sanitize_text_field( wp_unslash( $_GET ['_wpnonce'] ) );

			if ( ! wp_verify_nonce( $nonce, 'ect_nonce' ) ) {

				die( 'Nonce value cannot be verified.' );

			} else {

				if ( isset( $_GET ['cat'] ) ) {

					$ect_tax_query_cat = array(
						'taxonomy' => 'product_cat',
						'field'    => 'slug',
						'terms'    => sanitize_text_field( wp_unslash( $_GET['cat'] ) ),
					);
				}

				if ( isset( $_GET['tag'] ) ) {

					$ect_tax_query_tag = array(
						'taxonomy' => 'product_tag',
						'field'    => 'slug',
						'terms'    => sanitize_text_field( wp_unslash( $_GET['tag'] ) ),
					);
				}
			}
		}

		$args = array(
			'posts_per_page' => $count,
			'post_type'      => 'product',
			'post_status'    => 'publish',
			'tax_query'      => array(
				'relation' => 'AND',
				$ect_tax_query_featured,
				$ect_tax_query_cat,
				$ect_tax_query_tag,
			),
			'meta_query'     => $ect_meta_query,
		);

		$the_query = new WP_Query( $args );

		if ( $the_query->have_posts() ) {

			echo "<div class='ect_table_wrapper'>";
			ECT_Front_End::ecpt_generate_message();
			echo "<div id='ect_single_heading' class='ect_table' style='display: grid; grid-template-columns: " . esc_attr( ECT_Front_End::ectp_get_fraction( $ect_table_settings ) ) . " 20%;'>";
			ECT_Front_End::ectp_generate_heading( $ect_table_settings );
			echo '</div>';

			while ( $the_query->have_posts() ) {

				$the_query->the_post();
				$post_id     = get_the_ID();
				$ect_product = wc_get_product( $post_id );
				echo "<div id='ect_single_" . esc_attr( $post_id ) . "' class='ect_table' style='display: grid; grid-template-columns: " . esc_attr( ECT_Front_End::ectp_get_fraction( $ect_table_settings ) ) . " 20%;'>";
				ECT_Front_End::ectp_generate_table( $ect_product, $post_id, $ect_table_settings, $ect_table_options );
				echo '</div>';

				if ( $ect_product->has_child() && 'checked' === $ect_table_options['ect_variations_table'] && empty( get_post_meta( $post_id, '_children' )[0] ) ) {

					$ect_var = $ect_product->get_available_variations();

					foreach ( $ect_var as $attr ) {

						echo "<div id='ect_single_" . esc_attr( $post_id ) . "' class='ect_table ect_variable' style='display: grid; grid-template-columns: " . esc_attr( ECT_Front_End::get_var_fraction( $attr ) ) . " 22.2%;'>";
						ECT_Front_End::ectp_variable_table( $attr, $post_id, $ect_table_settings, $ect_table_options );
						echo '</div>';

					}
				}
			}

			$arr = wp_json_encode( $ect_table_settings );
			echo "<input type='hidden' id='ect_table_settings' value='" . esc_attr( $arr ) . "'>";
			echo '</div>';

		} else {
			echo '<div><h3>No Products To Display!</h3></div>';
		}
		$table = ob_get_contents();
		ob_get_clean();
		if ( ! $ect_table_settings ) {
			return '<div><h3>Table does not exists!</h3></div>';
		}
		return $table;
	}
}

if ( function_exists( 'ectp_tabular_posts' ) ) {

	add_shortcode( 'ect-table', 'ectp_tabular_posts' );

}
